import React from 'react';
import { VariableSizeList as List } from 'react-window';
export type ItemRenderer<T> = (item: T, ref: React.Ref<HTMLDivElement>, index: number) => React.ReactNode;
export type VirtualListRef = React.MutableRefObject<List | null>;
export type VirtualListProps<T> = {
    /** Items to render using the virtual list */
    items: T[];
    /**
     * Render prop expected to return a ReactNode that will be provided with:
     * - the item being rendered
     * - a ReactRef that it should attach to the container that is expecting
     *   resizes from within
     * - the index of item being rendered
     * */
    renderItem: ItemRenderer<T>;
    /**
     * Function which is used to calculate initial approximate height of the item
     * before it is rendered for the first time. The VirtualList, immediately
     * after first render, starts monitoring the actual height but it is still
     * super useful to avoid a huge flicker during the initial rendering phase
     */
    estimateItemInitialHeight(item: T): number;
    /**
     * How many items to keep rendered outside of the visible viewport. Keeping
     * this number higher reduces the blanks that we see when scrolling fast and
     * keeping it low removes the (possible) scroll jitters towards the scroll end
     * (observed at-least when used in conjunction with CodeMirror editor)
     */
    overScanCount?: number;
    /**
     * The space in pixels to be used as gutter in between the list items. It is
     * advisable to use this prop instead of css margins
     */
    rowGap?: number;
    /**
     * The class applied to the outer container of the virtual list.
     *
     * VirtualList renders two containers:
     * - an outer container which is rendered with a particular width and height
     *   provided by the AutoSizer, which never exceeds the visible and available
     *   viewport. This is the scrollable container as well
     * - an inner container which has a calculated height equal to that of the
     *   total size of the items rendered within it and this is the container that
     *   scrolls within the outer container
     */
    listOuterContainerClassName?: string;
    /**
     * Attribute value for data-testid for the root container of the list
     */
    dataTestId?: string;
    /**
     * Attribute value for data-testid for the container of the list item
     */
    itemDataTestId?: string;
    /**
     * Initial scrollTop value on first render of the list. Helpful to preserve
     * the scrollTop value in between list mounts / unmounts.
     *
     * Note - Use scrollableContainerRef to get a hold of scroll container to
     * retrieve the current scrollTop
     */
    initialScrollTop?: number;
    /**
     * React.Ref passed to the element that overflows in the vertical direction.
     * Helpful to retrieve the value of current scrollTop
     */
    scrollableContainerRef?: React.Ref<HTMLDivElement>;
    /**
     * WARNING: Use only when testing because the AutoSizer will be
     * disabled during tests
     *
     * Renders the VirtualList with the provided width
     */
    __TEST_LIST_WIDTH?: number;
    /**
     * WARNING: Use only when testing because the AutoSizer will be
     * disabled during tests
     *
     * Renders the VirtualList with the provided height
     */
    __TEST_LIST_HEIGHT?: number;
    /**
     * WARNING: Use only when testing
     *
     * Mutable Ref object to hold the reference to the VariableSizeList
     */
    __TEST_LIST_REF?: VirtualListRef;
};
export declare function VirtualList<T>({ items, estimateItemInitialHeight, renderItem, overScanCount, rowGap, listOuterContainerClassName, dataTestId, itemDataTestId, initialScrollTop, scrollableContainerRef, __TEST_LIST_WIDTH, __TEST_LIST_HEIGHT, __TEST_LIST_REF, }: VirtualListProps<T>): React.JSX.Element;
//# sourceMappingURL=virtual-list.d.ts.map